@@ -54,7 +54,10 @@ def _are_equal_exc_info_tuples(ei1, ei2):
     # copy_exc_info above.
     if ei1[0] is not ei2[0]:
         return False
-    if not all((type(ei1[1]) == type(ei2[1]),
+    # NOTE(dhellmann): The flake8/pep8 error E721 does not apply here
+    # because we want the types to be exactly the same, not just have
+    # one be inherited from the other.
+    if not all((type(ei1[1]) == type(ei2[1]),  # noqa: E721
                 _exception_message(ei1[1]) == _exception_message(ei2[1]),
                 repr(ei1[1]) == repr(ei2[1]))):
         return False
@@ -117,8 +120,8 @@ class Failure(mixins.StrMixin):
       to have code ran when this happens, and this can cause issues and
       side-effects that the receiver would not have intended to have caused).
 
-    TODO(harlowja): use parts of http://bugs.python.org/issue17911 and the
-    backport at https://pypi.python.org/pypi/traceback2/ to (hopefully)
+    TODO(harlowja): use parts of :pybug:`17911` and the
+    backport at https://pypi.org/project/traceback2/ to (hopefully)
     simplify the methods and contents of this object...
     """
     DICT_VERSION = 1
@@ -324,7 +327,7 @@ class Failure(mixins.StrMixin):
         """Re-raise exceptions if argument is not empty.
 
         If argument is empty list/tuple/iterator, this method returns
-        None. If argument is coverted into a list with a
+        None. If argument is converted into a list with a
         single ``Failure`` object in it, that failure is reraised. Else, a
         :class:`~taskflow.exceptions.WrappedFailure` exception
         is raised with the failure list as causes.
@@ -378,9 +381,9 @@ class Failure(mixins.StrMixin):
             #
             # See: https://www.python.org/dev/peps/pep-0415/ for why/what
             # the '__suppress_context__' is/means/implies...
-            supress_context = getattr(exc_val,
-                                      '__suppress_context__', False)
-            if supress_context:
+            suppress_context = getattr(exc_val,
+                                       '__suppress_context__', False)
+            if suppress_context:
                 attr_lookups = ['__cause__']
             else:
                 attr_lookups = ['__cause__', '__context__']
@@ -499,14 +502,18 @@ class Failure(mixins.StrMixin):
             data['causes'] = tuple(cls.from_dict(d) for d in causes)
         return cls(**data)
 
-    def to_dict(self):
-        """Converts this object to a dictionary."""
+    def to_dict(self, include_args=True):
+        """Converts this object to a dictionary.
+
+        :param include_args: boolean indicating whether to include the
+                             exception args in the output.
+        """
         return {
             'exception_str': self.exception_str,
             'traceback_str': self.traceback_str,
             'exc_type_names': list(self),
             'version': self.DICT_VERSION,
-            'exc_args': self.exception_args,
+            'exc_args': self.exception_args if include_args else tuple(),
             'causes': [f.to_dict() for f in self.causes],
         }
 
